@@ -168,7 +168,8 @@ class Actions:
             try:
                 t = self.finder.timeouts[timeout.lower()]
             except KeyError:
-                raise ValueError(f'Invalid timeout variant: "{timeout}", use {self.finder.timeouts.keys()}')
+                valid_options = list(self.finder.timeouts.keys())
+                raise ValueError(f'Invalid timeout variant: "{timeout}", use {valid_options}')
         if explicit_timeout is not None: t = explicit_timeout
         logger.info(f'wait for {condition}, timeout: {t} sec')
         WebDriverWait(self.webdriver, t).until(condition)
