@@ -130,7 +130,7 @@ class Finder(ABC):
             if k not in valid_variants:
                 raise ValueError(f'Invalid timeout variant {k}, use {valid_variants}')
         self.timeouts = timeouts
-        logger = logging.getLogger('FINDER')
+        logger = logging.getLogger('FINDER')  # todo: wyjac ten logger na zew
         stream_handler = logging.StreamHandler(sys.stdout)
         logger.addHandler(stream_handler)
         self.logger = logger
@@ -167,7 +167,8 @@ class FluentFinder(Finder):
         try:
             t = self.timeouts[timeout.lower()] if timeout is not None else self.default_timeout
         except KeyError:
-            raise ValueError(f'Invalid timeout variant: "{timeout}", use {self.timeouts.keys()}')
+            valid_options = list(self.timeouts.keys())
+            raise ValueError(f'Invalid timeout variant: "{timeout}", use {valid_options}')
         if explicit_timeout: t = explicit_timeout
         con = EC.presence_of_element_located(locator_tuple)
         self.logger.debug(f'find_element: {locator_tuple}, timeout: {t} sec, condition: {con}')
@@ -177,7 +178,8 @@ class FluentFinder(Finder):
         try:
             t = self.timeouts[timeout.lower()] if timeout is not None else self.default_timeout
         except KeyError:
-            raise ValueError(f'Invalid timeout variant: "{timeout}", use {self.timeouts.keys()}')
+            valid_options = list(self.timeouts.keys())
+            raise ValueError(f'Invalid timeout variant: "{timeout}", use {valid_options}')
         if explicit_timeout: t = explicit_timeout
         con = EC.presence_of_all_elements_located(locator_tuple)
         self.logger.debug(f'find_elements: {locator_tuple}, timeout: {t} sec, condition: {con}')
